Term

Enum Term 

pub enum Term {
    NamedNode(IriBuf),
    Literal(Literal),
    BlankNode(BlankNode),
    TripleTerm(Arc<Triple>),
}
https://www.w3.org/TR/rdf11-concepts/#section-triples

Variants



NamedNode(IriBuf)



Literal(Literal)



BlankNode(BlankNode)



TripleTerm(Arc<Triple>)

Implementations

Source

impl Term

pub fn into_iri(self) -> Result<IriBuf, TermError>

pub fn into_literal(self) -> Result<Literal, TermError>

pub fn into_blank_node(self) -> Result<BlankNode, TermError>

pub fn into_triple_term(self) -> Result<Arc<Triple>, TermError>

pub fn to_iri(&self) -> Result<&IriBuf, TermError>

pub fn to_literal(&self) -> Result<&Literal, TermError>

pub fn to_blank_node(&self) -> Result<&BlankNode, TermError>

pub fn to_triple_term(&self) -> Result<&Arc<Triple>, TermError>

pub fn is_named_node(&self) -> bool

pub fn is_blank_node(&self) -> bool

pub fn is_literal(&self) -> bool

pub fn is_triple_term(&self) -> bool

pub fn ground(&self) -> bool

Checks whether term is ground as defined by RDF Concepts and Abstract Syntax

A term is ground if it is not a blank node or a triple term containing a blank node.

Example
use taganak_core::terms::Term;
use std::sync::Arc;

let nn: Arc<Term> = Arc::new("<https://example.com/foo>".try_into().unwrap());
let bn: Arc<Term> = Arc::new("_:b1".try_into().unwrap());
let li: Arc<Term> = Arc::new(r#""Something""#.try_into().unwrap());

assert_eq!(nn.ground(), true);
assert_eq!(li.ground(), true);
assert_eq!(bn.ground(), false);